@@ -38,12 +38,12 @@ _pkg_config = {
     'py_version':         0x020710,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'sip_inc_dir':        '/usr/include/python2.7',
     'sip_module_dir':     '/usr/lib/python2.7/site-packages',
     'sip_root_dir':       '/usr/lib/python2.7/site-packages',
-    'sip_version':        0x041310,
-    'sip_version_str':    '4.19.16',
+    'sip_version':        0x041311,
+    'sip_version_str':    '4.19.17',
     'universal':          ''
 }
 
@@ -51,7 +51,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong -fno-plt',
+    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
